"""
Settings for django-recaptcha module
"""
INSTALLED_APPS = add_to_tuple(INSTALLED_APPS, 'captcha')

# You MUST edit the following keys with your reCaptcha account keys
RECAPTCHA_PUBLIC_KEY = 'dummy-public'
RECAPTCHA_PRIVATE_KEY = 'dummy-private'



# -*- coding: utf-8 -*-
"""
Mod for "djangocms_text_ckeditor", a djangocms plugin to use CKEditor (4.x) instead of the default one

This mod contains some tricks to enabled "django-filebrowser" usage with "image" plugin from CKEditor.

And some contained patches/fixes :

* the codemirror plugin that is not included in djangocms-text-ckeditor;
* Some missed images for the "showblocks" plugin;
* A system to use the "template" plugin (see views.EditorTemplatesListView for more usage details);
* Some patch/overwrites to have content preview and editor more near to Foundation;

Links :

* https://github.com/divio/djangocms-text-ckeditor/
* http://ckeditor.com/
* http://docs.ckeditor.com

Flaws :

* Impossible actuellement d'intégrer Foundation dans l'éditeur parce que F3 force une propriété CSS qui gênent la disposition attendu par l'éditeur, nottement sur le plugin ckeditor magicdiv qui est indispensable;
* Dans les pages CMS, L'éditeur a un mauvais comportement de positionnement : il est bien trop petit, le fullscreen ne sert quasiment à rien et les fenetres modal sont mal positionnés. Le rendu du contenu juste au dessus de l'éditeur doit y être pour quelque chose..
* CKEditor n'aime pas les balises de liens "<a>" qui englobe un ou plusieurs éléments de type "bloc", il les réécrient comme il les aiment. S'il ne le faisait pas cela pourrait gener l'édition.
"""


# -*- coding: utf-8 -*-

INSTALLED_APPS = add_to_tuple(INSTALLED_APPS,
    'django.contrib.comments',
    'tagging',
    'zinnia',
    'cmsplugin_zinnia')

# Enable ckeditor usage for entries editor
ZINNIA_WYSIWYG = "ckeditor"

# List entries by ..
ZINNIA_PAGINATION = 3

TEMPLATE_CONTEXT_PROCESSORS += (
    'zinnia.context_processors.version',)



# -*- coding: utf-8 -*-
from django.conf import settings
from staticpages.urls import loaders

if settings.DEBUG:
    urlpatterns = patterns('', *loaders.mount_staticpages(*settings.STATICPAGES_PROTOTYPES)) + urlpatterns



# -*- coding: utf-8 -*-
import os

INSTALLED_APPS = add_to_tuple(INSTALLED_APPS, 'djangocms_text_ckeditor')

STATICFILES_DIRS += ( os.path.join(MOD_FILE, "static"),)
TEMPLATE_DIRS += (os.path.join(MOD_FILE, "templates"),)

# On redéfinit les settings pour y inclure les affinements de configuration de l'éditeur
CKEDITOR_SETTINGS = {
    'language': '{{ language }}',
    'toolbar': 'CMS',
    'skin': 'moono',
    'toolbarCanCollapse': False,
    'contentsCss': "/static/css/ckeditor.css",
    'toolbar_CMS': [
        ['Undo', 'Redo'],
        ['cmsplugins', '-', 'ShowBlocks'],
        ['Format', 'Styles'],
        #['RemoveFormat', '-', '', 'PasteText', 'PasteFromWord'],
        ['RemoveFormat', '', '', '', ''],
        ['Maximize', ''],
        '/',
        ['Source', '-', 'searchCode', 'autoFormat', '-', 'CommentSelectedRange', 'UncommentSelectedRange', '', ''],
        '/',
        ['Bold', 'Italic', 'Underline', '-', 'Subscript', 'Superscript', '', ''],
        ['JustifyLeft', 'JustifyCenter', 'JustifyRight', '', '', '', ''],
        ['Link', 'Unlink'],
        ['Image', '-', 'NumberedList', 'BulletedList', '-', 'Table', '-', 'CreateDiv', 'HorizontalRule', 'SpecialChar', '-', 'Templates'],
        # , 'Iframe' # Disabled because djangocms seems to sanitize it from the posted HTML
    ],
    # Utilise des class CSS de Foundation pour le plugin d'alignement de texte (justify)
    'justifyClasses': [ 'text-left', 'text-center', 'text-right', 'AlignJustify' ],
    # Active par défaut l'affichage de la signalisation des blocs
    'startupOutlineBlocks': True,
    # Case "Remplacer le contenu actuel" décochée par défaut
    'templates_replaceContent': False,
    # Urls du script définissant les templates de contenu
    'templates_files': [
        '/ckeditor/editor_site_templates.js'
    ],
    # Redéfinition pour activer le plugin codemirror
    'extraPlugins': 'cmsplugins,codemirror',
    # Lien pour activer "Explorer le serveur" au travers de django-filebrowser
    'filebrowserBrowseUrl': "/admin/filebrowser/browse?pop=3",
    # Utile pour temporairement désactiver le menu de contexte (clic droit) et plugins 
    # dépendants dans l'éditeur
    #'removePlugins': 'liststyle,tabletools,scayt,menubutton,contextmenu',
}

# Chemin relatif du répertoire contenant les templates de contenu pour l'éditeur
CKEDITOR_EDITOR_TEMPLATES_PATH = "ckeditor/editor-site-templates/"
# Chemin relatif du répertoire contenant la représentation en image du contenu pour 
# l'éditeur
CKEDITOR_EDITOR_TEMPLATES_IMAGES_PATH = "ckeditor/editor-site-templates/"
# Nom de fichier à rechercher pour le manifest des templates de contenu, relatif au 
# chemin de CKEDITOR_EDITOR_TEMPLATES_PATH
CKEDITOR_EDITOR_TEMPLATES_NAMES_FILE = "manifest.json"
# Template string du code Javascript de base où injecter la définition des templates de 
# contenus trouvés
# Empeche les balises auto fermantes de XHTML
CKEDITOR_EDITOR_JS_TEMPLATE = u"""CKEDITOR.addTemplates( 'default', {{imagesPath:"{imagespath}", templates: {json_list}}});"""



# -*- coding: utf-8 -*-

INSTALLED_APPS = add_to_tuple(INSTALLED_APPS, 'django_assets')

ASSETS_DEBUG = DEBUG
ASSETS_ROOT = join(PROJECT_PATH, 'webapp_statics/')
STATICFILES_DIRS += (ASSETS_ROOT,)
ASSETS_MODULES = (
    'project.assets',
)



# -*- coding: utf-8 -*-
from django.conf import settings
from django.contrib.sites.models import Site


def get_site_metas(with_static=False, with_media=False, is_secure=False,
                   extra={}):
    """
    Return metas from the current *Site* and settings

    Added Site metas will be callable in templates like this
    ``SITE.themetaname``

    This can be used in code out of a Django requests (like in management
    commands) or in a context processor to get the *Site* urls.

    Default metas returned :

    * name: Current *Site* entry name;
    * domain: Current *Site* entry domain;
    * web_url: The Current *Site* entry domain prefixed with the http
      protocol;

    Optionally it can also return ``STATIC_URL`` and ``MEDIA_URL`` if needed
    (like out of Django requests).
    """
    site_current = Site.objects.get_current()
    metas = {
        'SITE': {
            'name': site_current.name,
            'domain': site_current.domain,
            'web_url': 'http://%s' % site_current.domain,
        }
    }
    if is_secure:
        metas['web_url'] = 'https://%s' % site_current.domain
    if with_media:
        metas['MEDIA_URL'] = getattr(settings, 'MEDIA_URL', '')
    if with_static:
        metas['STATIC_URL'] = getattr(settings, 'STATIC_URL', '')
    metas.update(extra)
    return metas


def site_metas(request):
    """
    Context processor to add the current *Site* metas to the context
    """
    return get_site_metas(is_secure=request.is_secure())



# -*- coding: utf-8 -*-
"""
Forms for contact forms
"""
from django.conf import settings
from django.contrib.sites.models import Site
from django.core.mail import send_mail
from django.forms import ModelForm, Textarea
from django.template.loader import render_to_string
from django.utils.translation import ugettext_lazy as _

from project.utils.context_processors import get_site_metas

from crispy_forms.helper import FormHelper
from crispy_forms_foundation.layout import Layout, Field, Fieldset, Row, Column, HTML, ButtonHolder, ButtonHolderPanel, Submit, InlineField, InlineJustifiedField

#from captcha.fields import ReCaptchaField

from .models import CIVILITY_CHOICES, ContactBase, Contact

def SimpleRowColumn(field, *args, **kwargs):
    """
    Shortcut for simple row with only a full column
    """
    if isinstance(field, basestring):
        field = Field(field, *args, **kwargs)
    return Row(
        Column(field),
    )

class ContactFormBase(ModelForm):
    """
    Contact base form, you cant use it directly because the used 
    model ('ContactBase') is just an abstract model
    """
    error_css_class = 'error'
    required_css_class = 'required'
    mail_subject_template = 'contact_form/contact_form_subject.txt'
    mail_content_template = 'contact_form/contact_form.txt'
   
    def __init__(self, *args, **kwargs):
        super(ContactFormBase, self).__init__(*args, **kwargs)
        
        self.helper = FormHelper()
        self.helper.form_action = '.'

    def save(self, commit=True):
        """Save and send"""
        contact = super(ContactFormBase, self).save()
        context = {'contact': contact}
        context.update(get_site_metas())

        subject = ''.join(render_to_string(self.mail_subject_template, context).splitlines())
        content = render_to_string(self.mail_content_template, context)

        send_mail(subject, content,
                  settings.DEFAULT_FROM_EMAIL,
                  settings.CONTACT_FORM_TO,
                  fail_silently=not settings.DEBUG)

        return contact

    class Meta:
        model = ContactBase

class ContactForm(ContactFormBase):
    """Contact Form"""
    def __init__(self, *args, **kwargs):
        super(ContactFormBase, self).__init__(*args, **kwargs)
        
        self.fields['civility'].choices = (('', _('civility')),) + CIVILITY_CHOICES
        
        self.helper = FormHelper()
        self.helper.attrs = {'data_abide': ''}
        self.helper.form_action = '.'
        self.helper.add_input(Submit('submit', _('Submit')))

    class Meta:
        model = Contact



from project.settings import *

DEBUG = False

ASSETS_DEBUG = False
ASSETS_ROOT = STATIC_ROOT
ASSETS_AUTO_BUILD = False

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'NAME': '',
        'USER': '',
        'PASSWORD': '',
        'HOST': 'localhost',
        'PORT': '',               # Set to empty string for default.
    }
}



# -*- coding: utf-8 -*-
"""
Using crispy_forms with Foundation set
"""

INSTALLED_APPS = add_to_tuple(INSTALLED_APPS, 'crispy_forms', 'crispy_forms_foundation')

CRISPY_FAIL_SILENTLY = not DEBUG

# Default layout to use with "crispy_forms"
CRISPY_TEMPLATE_PACK = 'foundation-5'



# -*- coding: utf-8 -*-
"""
Map your flatpages urls
"""
# You can map them on a single entry point
#urlpatterns = patterns('',
    #('^pages/', include('django.contrib.flatpages.urls')),
#) + urlpatterns

# OR you can hardcode your flatpages here, this is more easy to avoid clash within a big 
# project with only some flatpages
#urlpatterns = patterns('django.contrib.flatpages.views',
    #url(r'^your-page/$', 'flatpage', {'url': '/your-page/'}, name='your-page'),
#) + urlpatterns


# -*- coding: utf-8 -*-

MIDDLEWARE_CLASSES = add_to_tuple(MIDDLEWARE_CLASSES,
    'django.middleware.locale.LocaleMiddleware',
    before='django.middleware.common.CommonMiddleware')

MIDDLEWARE_CLASSES += (
    'django.middleware.doc.XViewMiddleware',
    'cms.middleware.page.CurrentPageMiddleware',
    'cms.middleware.user.CurrentUserMiddleware',
    'cms.middleware.toolbar.ToolbarMiddleware',
    'cms.middleware.language.LanguageCookieMiddleware',
)

INSTALLED_APPS = add_to_tuple(INSTALLED_APPS,
    'cms',
    'mptt',
    'menus',
    'sekizai',
    # Plugins
    'cms.plugins.picture',
    'snippet', # Snippet plugin fork
    #'cms.plugins.snippet', # Original snippet plugin
    # Default text plugin disabled to use `djangocms_text_ckeditor` instead, see "ckeditor" mod
    #'cms.plugins.text',
    # Commonly unused plugins
    #'cms.plugins.file',
    #'cms.plugins.flash',
    #'cms.plugins.googlemap',
    #'cms.plugins.link',
    #'cms.plugins.teaser',
    #'cms.plugins.twitter',
    #'cms.plugins.video',
)

TEMPLATE_CONTEXT_PROCESSORS = add_to_tuple(TEMPLATE_CONTEXT_PROCESSORS,
    'django.contrib.auth.context_processors.auth',
    'django.core.context_processors.i18n',
    'django.core.context_processors.request',
    'django.core.context_processors.media',
    'django.core.context_processors.static',
    'cms.context_processors.media',
    'sekizai.context_processors.sekizai',
)

CMS_TEMPLATES = (
    ('cms/1_cols.html', '1 column'),
    ('cms/2_cols.html', '2 columns'),
    ('cms/3_cols.html', '3 columns'),
)

CMS_REDIRECTS = True
CMS_SEO_FIELDS = True
CMS_SOFTROOT = True

# Djangocodemirror settings for cms_snippet plugin
CODEMIRROR_SETTINGS = {
    'cms_snippet': {
        'mode': "xml",
        'lineWrapping': True,
        'lineNumbers': True,
        'search_enabled': True,
        'embed_settings': True,
        'add_jquery': True,
        'lib_buttons_path': 'djangocodemirror/snippet_buttons.js',
    },
}



#!/usr/bin/env python
"""
A tiny script to rename filename prefix with dot in filename prefixed with 
"+dot+" to ensure correct naming after updating Foundation5 sources

Just execute it here, and the updated sources will be ready to be committed.
"""
import os

for root, dirs, files in os.walk(os.path.dirname(__file__)):
    for name in files:
        if name.startswith('.'):
            current_path = os.path.join(root, name)
            new_name = "+dot+{0}".format(name[1:])
            new_path = os.path.join(root, new_name)
            print current_path, '=>', new_path
            # Remove previous file it it exists (this should not be)
            if os.path.exists(new_path):
                os.remove(new_path)
            # Then rename it
            os.rename(current_path, new_path)


# -*- coding: utf-8 -*-
"""
Common templates tags for porticus
"""
#from django.conf import settings
from django import template
from django.utils.safestring import mark_safe
from django.shortcuts import get_object_or_404
from django.conf import settings

from porticus.models import Gallery, Album

gettext = lambda s: s

register = template.Library()

def locale_title(locale_name):
    """
    Giving a locale name return its title, taken from the settings.EXTRA_COUNTRY_LOCALES
    
    If the locale is not in the settings.EXTRA_COUNTRY_LOCALES, return it unchanged
    """
    l = dict(settings.EXTRA_COUNTRY_LOCALES)
    if locale_name not in l:
        return locale_name
    return l.get(locale_name)

register.simple_tag(locale_title)
register.filter('locale_title', locale_title)

def is_valid_locale_name(locale_name):
    """
    Giving a locale name return a boolean wether the locale is in settings.EXTRA_COUNTRY_LOCALES or not
    """
    return (locale_name in dict(settings.EXTRA_COUNTRY_LOCALES))

register.assignment_tag(is_valid_locale_name)



# -*- coding: utf-8 -*-
"""
Include the urls map from django-cms
"""
# Common cms url map for one language only
urlpatterns += patterns('', url(r'^', include('cms.urls')))

# Remove the previous code line and uncomment the followings to support multiple languages
#from django.conf.urls.i18n import i18n_patterns

#urlpatterns += i18n_patterns('', url(r'^', include('cms.urls')))



# -*- coding: UTF-8 -*-

# Import from the Standard Library
from os import getcwd, symlink
from os.path import dirname, join
from random import choice
from subprocess import Popen, PIPE
from sys import modules, exit

# Import from PasteScript
from paste.script.templates import Template, var
from __init__ import __version__ as template_version

class Caller(object):

    def __init__(self, cwd=None):
        self.cwd = cwd


    def __call__(self, *args):
        popen = Popen(args, stdout=PIPE, stderr=PIPE, cwd=self.cwd)
        out, err = popen.communicate()
        if popen.returncode != 0:
            print args
            print 'Exit %d' % popen.returncode
            exit(popen.returncode)
        return out



class Django(Template):

    summary = "Django project."
    _template_dir = 'django_buildout'
    vars = [
        var('admin_tools', 'Enable admin_tools (yes/no)', default='yes'),
        var('accounts', 'Enable accounts registration (yes/no)', default='yes'),
        var('contact_form', 'Enable contact_form (yes/no)', default='yes'),
        #var('debug_toolbar', 'Enable debug_toolbar (yes/no)', default='yes'),
        var('porticus', 'Enable porticus (yes/no)', default='yes'),
        var('site_metas', 'Enable site_metas (yes/no)', default='yes'),
        var('slideshows', 'Enable Slideshows (yes/no)', default='yes'),
        var('zinnia', 'Enable Zinnia (yes/no)', default='yes'),
        ]


    def pre(self, command, output_dir, kw):
        # secret_key
        chars = 'abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)'
        kw['secret_key'] = ''.join([ choice(chars) for i in range(50) ])

        # template version
        kw['epaster_template_name'] = 'emencia-paste-django'
        kw['epaster_template_version'] = template_version


    def post(self, command, output_dir, vars):
        if command.simulate:
            return

        # 1. Mods
        mods = [
            var.name for var in self.vars if vars[var.name].lower() == 'yes' ]
        mods = set(mods)

        # Required
        mods.add('emencia_utils')       # Useful utilities
        mods.add('sitemap')   # Common sitemap for djangocms and other apps
        mods.add('assets')       # Used in templates
        mods.add('google_tools') # Used in templates
        mods.add('cms')
        mods.add('filebrowser') # Used in djangocms and zinnia
        mods.add('ckeditor')     # Used in djangocms and zinnia
        mods.add('codemirror')   # Used in snippet cms plugin
        
        # Conditionnal dependancies
        if 'contact_form' in mods:
            mods.add('crispy_forms')
            mods.add('recaptcha')

        # Enable
        project = join(getcwd(), vars['project'], 'project')
        for name in mods:
            symlink(
                join('..', 'mods_available', name),
                join(project, 'mods_enabled', name))

        # 2. Git initialization
        call = Caller(vars['project'])
        call('git', 'init', '.')                    # init
        call('git', 'add', '.')                     # add
        call('git', 'commit', '-m', 'First commit') # commit



"""
Mods for "django-pdb" :

https://github.com/tomchristie/django-pdb

Generally this Python module is not included in the buildout, you will probably have 
to install it yourself (with "pip")

See the the django-pdb Readme for more usage details.

WARNING: django-pdb should be put at the end of settings.INSTALLED_APPS :
        "Make sure to put django_pdb after any conflicting apps in INSTALLED_APPS so 
        that they have priority."
        
        So with the automatic loading system for the mods, you should enable it with a 
        name like "zpdb", to assure that it is loaded at the end of the loading loop.
"""


from django import forms
from django.utils.translation import ugettext_lazy as _

from django.contrib.auth.forms import AuthenticationForm, PasswordChangeForm, PasswordResetForm, SetPasswordForm

from crispy_forms.helper import FormHelper
from crispy_forms_foundation.layout import Layout, Fieldset, Row, Column, ButtonHolder, Submit

from registration.forms import RegistrationFormUniqueEmail

def dummy_form_helper():
    """
    Return a very simple form helper that will only display the input fields from the 
    form and the csrf.
    
    <form/> tag and submit button is at your charge in the templates, fields are 
    automatically selected from the form and csrf is inserted.
    """
    helper = FormHelper()
    helper.form_tag = False
    
    return helper

class AuthenticationFormAccounts(AuthenticationForm):
    """
    Override the default form to add a very simple crispy_forms helper
    """
    def __init__(self, *args, **kwargs):
        self.helper = dummy_form_helper()
        
        super(AuthenticationFormAccounts, self).__init__(*args, **kwargs)

class PasswordChangeFormAccounts(PasswordChangeForm):
    """
    Override the default form to add a very simple crispy_forms helper
    """
    def __init__(self, *args, **kwargs):
        self.helper = dummy_form_helper()
        
        super(PasswordChangeFormAccounts, self).__init__(*args, **kwargs)

class PasswordResetFormAccounts(PasswordResetForm):
    """
    Override the default form to add a very simple crispy_forms helper
    """
    def __init__(self, *args, **kwargs):
        self.helper = dummy_form_helper()
        
        super(PasswordResetFormAccounts, self).__init__(*args, **kwargs)

class SetPasswordFormAccounts(SetPasswordForm):
    """
    Override the default form to add a very simple crispy_forms helper
    """
    def __init__(self, *args, **kwargs):
        self.helper = dummy_form_helper()
        
        super(SetPasswordFormAccounts, self).__init__(*args, **kwargs)



class RegistrationFormAccounts(RegistrationFormUniqueEmail):
    """
    Form for registration
    """
    firstname = forms.CharField(label=_('Firstname'), required=False)
    lastname = forms.CharField(label=_('Lastname'))
    company = forms.CharField(label=_('Company'))
    function = forms.CharField(label=_('Function'))
    address = forms.CharField(label=_('Address'), required=False, widget=forms.Textarea(attrs={'rows':3}))
    postal_code = forms.CharField(label=_('Postal code'), required=False)
    city = forms.CharField(label=_('City'), required=False)
    country = forms.CharField(label=_('Country'), required=False)
    phone = forms.CharField(label=_('Professional phone number'), required=False)
    
    def __init__(self, *args, **kwargs):
        self.helper = FormHelper()
        self.helper.form_action = '.'
        self.helper.layout = Layout(
            Fieldset(
                _('User'),
                Row(
                    Column(
                        'username',
                        css_class='six'
                    ),
                    Column(
                        Row(
                            Column(
                                'password1',
                                css_class='six unpadded'
                            ),
                            Column(
                                'password2',
                                css_class='six unpadded'
                            ),
                        ),
                        css_class='six'
                    ),
                ),
            ),
            Fieldset(
                _('Society'),
                Row(
                    Column(
                        'company',
                        css_class='six'
                    ),
                    Column(
                        'function',
                        css_class='six'
                    ),
                ),
            ),
            Fieldset(
                _('Personal details'),
                Row(
                    Column(
                        Row(
                            Column(
                                'firstname',
                                css_class='six unpadded'
                            ),
                            Column(
                                'lastname',
                                css_class='six unpadded'
                            ),
                        ),
                        css_class='six'
                    ),
                    Column(
                        'email',
                        css_class='six'
                    ),
                ),
                Row(
                    Column(
                        'address',
                        css_class='six'
                    ),
                    Column(
                        Row(
                            Column(
                                'city',
                                css_class='eight unpadded'
                            ),
                            Column(
                                'postal_code',
                                css_class='four unpadded'
                            ),
                            Column(
                                'country',
                                css_class='six unpadded'
                            ),
                            Column(
                                'phone',
                                css_class='six unpadded'
                            ),
                        ),
                        css_class='six'
                    ),
                ),
            ),
            Row(
                Column(
                    ButtonHolder( Submit('submit', _('Submit')), css_class="text-right" ),
                    css_class='twelve'
                ),
            )
        )
        
        super(RegistrationFormAccounts, self).__init__(*args, **kwargs)



# -*- coding: utf-8 -*-
INSTALLED_APPS = add_to_tuple(INSTALLED_APPS, 'project.accounts', 'registration')

ACCOUNT_ACTIVATION_DAYS = 7
DEFAULT_FROM_EMAIL = 'noreply@dummy.com'

# Default URL to redirect to just after successful login
LOGIN_REDIRECT_URL = "/"

DEFAULT_ACTIVE_SUBSCRIBE_EMAILS = []
CONTACT_FORM_EMAILS = []



# -*- coding: utf-8 -*-
"""
Models for contact forms
"""
from django.db import models
from django.utils.translation import ugettext_lazy as _

from emencia.django.countries.models import Country

CIVILITY_CHOICES = (
    (0, _('mlle')),
    (1, _('mme')),
    (2, _('mr')),
)

class ContactBase(models.Model):
    """Models for storing contact message"""
    creation_date = models.DateTimeField(_('creation date'), auto_now_add=True)

    civility = models.IntegerField(_('civility'), choices=CIVILITY_CHOICES)
    first_name = models.CharField(_('first name'), max_length=50)
    last_name = models.CharField(_('last name'), max_length=50)
    email = models.EmailField(_('email'))
    message = models.TextField(_('message'), blank=True)

    def __unicode__(self):
        return 'Contact from %s %s' % (self.first_name, self.last_name)

    class Meta:
        abstract = True
        verbose_name = _('contact')
        verbose_name_plural = _('contacts')

class Contact(ContactBase):
    """Default enabled model"""
    phone = models.CharField(_('phone'), max_length=15)
    company = models.CharField(_('company'), max_length=250, blank=True)
    city = models.CharField(_('city'), max_length=255, blank=True)
    state = models.CharField(_('state/province'), max_length=255, blank=True)
    country = models.ForeignKey(Country, verbose_name=_('country'), blank=True, null=True)
    optin_newsletter = models.BooleanField(_("do you wish to receive the newsletter?"))



# -*- coding: utf-8 -*-
import os

INSTALLED_APPS = add_to_tuple(INSTALLED_APPS, 'filebrowser',
                              before="djangocms_text_ckeditor")

# Needed for compatibility with filebrowser_no_grapelli that use
# ADMIN_MEDIA_PREFIX when tinymce is not installed, sadly this raise a
# warning by Django >= 1.5
ADMIN_MEDIA_PREFIX = os.path.join(STATIC_URL, "admin/")


FILEBROWSER_MAX_UPLOAD_SIZE = 20*1024*1024 # 20 Mb



# -*- coding: utf-8 -*-

INSTALLED_APPS = add_to_tuple(INSTALLED_APPS, 'sorl.thumbnail', 'slideshows')

# Available templates to display a slideshow
SLIDESHOWS_TEMPLATES = (
    ("slideshows/slides_show/default.html", "Slider default"),
    ("slideshows/slides_show/royalslider.html", "Royal slider"),
    ("slideshows/slides_show/interchange.html", "Interchange (for cms plugin only)"),
)

# Available config file to initialize your slideshow Javascript stuff
# (Paths are relative to a templates directory)
SLIDESHOWS_CONFIGS = (
    ("slideshows/slides_show/configs/default.html", "Slider default"),
    ("slideshows/slides_show/configs/fade_slider.html", "Slider with fade"),
)

# Available templates for "random slide" mode
SLIDESHOWS_RANDOM_SLIDE_TEMPLATES = (
    ("slideshows/random_slide/default.html", "Random image default"),
    ("slideshows/random_slide/interchange.html", "Interchange (for cms plugin only)"),
)

# Default templates to use in admin forms
DEFAULT_SLIDESHOWS_TEMPLATE = SLIDESHOWS_TEMPLATES[0][0]
DEFAULT_SLIDESHOWS_CONFIG = ""
DEFAULT_SLIDESHOWS_RANDOM_SLIDE_TEMPLATE = SLIDESHOWS_RANDOM_SLIDE_TEMPLATES[0][0]



# -*- coding: utf-8 -*-

# Import from the Standard Library
import os

# Import from django
from django.conf.urls import patterns, include, url
from django.conf import settings

# Uncomment the next two lines to enable the admin:
from django.contrib import admin
admin.autodiscover()


urlpatterns = patterns('',
    #url(r'^admin/doc/', include('django.contrib.admindocs.urls')), # Cause troubles with docutils usage like with codemirror
    url(r'^admin/', include(admin.site.urls)),
)

# Mods system
PROJECT_PATH = os.path.abspath(os.path.dirname(__file__))
mods = os.path.join(PROJECT_PATH, 'mods_enabled')
mods = [ os.path.join(mods, x) for x in os.listdir(mods) ]
mods.sort()
for mod in mods:
    mod = os.path.join(mod, 'urls.py')
    if os.path.isfile(mod):
        execfile(mod)

# Debug
if settings.DEBUG:
    urlpatterns = patterns('',
        url(r'^media/(?P<path>.*)$', 'django.views.static.serve',
            {'document_root': settings.MEDIA_ROOT, 'show_indexes': True}),
        url(r'', include('django.contrib.staticfiles.urls')),
    ) + urlpatterns



"""
Settings to use for development
"""
from settings import *

# Enable django-debug-toolbar for the following IPs
INTERNAL_IPS = ('127.0.0.1',)

# Test emails by looking at the console
EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'



from setuptools import setup, find_packages

setup(
    name='emencia-paste-django',
    version=__import__('emencia_paste_django').__version__,
    description=__import__('emencia_paste_django').__doc__,
    long_description=open('README.rst').read(),
    author='David Thenon',
    author_email='dthenon@emencia.com',
    url='https://github.com/emencia/emencia-paste-django',
    license='MIT',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Paste',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    install_requires=[
        'Paste',
        'PasteDeploy',
        'PasteScript',
        'zc.buildout',
        'zc.recipe.egg',
    ],
    entry_points={
        'paste.paster_create_template': [
            'django = emencia_paste_django.templates:Django',
        ]
    },
    include_package_data=True,
    zip_safe=False
)


# -*- coding: utf-8 -*-
from project.mods_enabled.ckeditor.views import EditorTemplatesListView

urlpatterns = patterns('',
    url(r'^ckeditor/editor_site_templates.js$', EditorTemplatesListView.as_view(), name="ckeditor-editor-site-templates"),
) + urlpatterns
